pub struct Color {
pub r: f32,
pub g: f32,
pub b: f32,
pub a: f32,
}Expand description
A color value with red, green, blue, and alpha channels, each in [0.0, 1.0].
Fields
r: f32g: f32b: f32a: f32Implementations
Sourceimpl Color
impl Color
Sourcepub const TRANSPARENT: Self
pub const TRANSPARENT: Self
Fully transparent black.
Sourcepub const fn rgb(r: f32, g: f32, b: f32) -> Self
pub const fn rgb(r: f32, g: f32, b: f32) -> Self
Creates an opaque color from RGB components in [0.0, 1.0].
Sourcepub const fn rgba(r: f32, g: f32, b: f32, a: f32) -> Self
pub const fn rgba(r: f32, g: f32, b: f32, a: f32) -> Self
Creates a color from RGBA components in [0.0, 1.0].
Sourcepub fn with_alpha(self, a: f32) -> Self
pub fn with_alpha(self, a: f32) -> Self
Returns a copy of this color with the alpha channel replaced by a.