RosaceTheme

Trait RosaceTheme 

pub trait RosaceTheme:
    Send
    + Sync
    + 'static {
    // Required method
    fn theme_data(&self) -> &ThemeData;
}
Implement this trait to supply a custom theme to the framework.

The bound Send + Sync + 'static ensures that theme objects can be stored in global statics and shared across threads.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors